Zaber module for *pyobs*
========================

Install *pyobs-zaber*
---------------------
Clone the repository:

    git clone https://github.com/pyobs/pyobs-zaber.git


And install it:

    cd pyobs-zaber
    pip3 install .

